==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/RedShift/DeleteHsmClientCertificate.pm <==

package Paws::RedShift::DeleteHsmClientCertificate;
  use Moose;
  has HsmClientCertificateIdentifier => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteHsmClientCertificate');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::DeleteHsmClientCertificate - Arguments for method DeleteHsmClientCertificate on Paws::RedShift

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteHsmClientCertificate on the 
Amazon Redshift service. Use the attributes of this class
as arguments to method DeleteHsmClientCertificate.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteHsmClientCertificate.

As an example:

  $service_obj->DeleteHsmClientCertificate(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> HsmClientCertificateIdentifier => Str

The identifier of the HSM client certificate to be deleted.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteHsmClientCertificate in L<Paws::RedShift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.45.tar.gz: Paws-0.45/lib/Paws/RedShift/DeleteHsmClientCertificate.pm <==

package Paws::RedShift::DeleteHsmClientCertificate;
  use Moose;
  has HsmClientCertificateIdentifier => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteHsmClientCertificate');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RedShift::DeleteHsmClientCertificate - Arguments for method DeleteHsmClientCertificate on L<Paws::RedShift>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteHsmClientCertificate on the
L<Amazon Redshift|Paws::RedShift> service. Use the attributes of this class
as arguments to method DeleteHsmClientCertificate.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteHsmClientCertificate.

=head1 SYNOPSIS

    my $redshift = Paws->service('RedShift');
    $redshift->DeleteHsmClientCertificate(
      HsmClientCertificateIdentifier => 'MyString',

    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/redshift/DeleteHsmClientCertificate>

=head1 ATTRIBUTES


=head2 B<REQUIRED> HsmClientCertificateIdentifier => Str

The identifier of the HSM client certificate to be deleted.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteHsmClientCertificate in L<Paws::RedShift>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
